@@ -1,7 +1,20 @@
-/*
- * Copyright 2002 Lite Speed Technologies Inc, All Rights Reserved.
- * LITE SPEED PROPRIETARY/CONFIDENTIAL.
- */
+/*****************************************************************************
+*    Open LiteSpeed is an open source HTTP server.                           *
+*    Copyright (C) 2013 - 2021  LiteSpeed Technologies, Inc.                 *
+*                                                                            *
+*    This program is free software: you can redistribute it and/or modify    *
+*    it under the terms of the GNU General Public License as published by    *
+*    the Free Software Foundation, either version 3 of the License, or       *
+*    (at your option) any later version.                                     *
+*                                                                            *
+*    This program is distributed in the hope that it will be useful,         *
+*    but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
+*    GNU General Public License for more details.                            *
+*                                                                            *
+*    You should have received a copy of the GNU General Public License       *
+*    along with this program. If not, see http://www.gnu.org/licenses/.      *
+*****************************************************************************/
 
 #include "adns.h"
 
@@ -16,6 +29,7 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
+#include <pthread.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -34,11 +48,13 @@ LS_SINGLETON(Adns);
 
 Adns::Adns()
     : m_pCtx( NULL )
-    , m_iCounter(0)
     , m_pShmHash(NULL)
+    , m_lockedBy(0)
     , m_tmLastTrim(0)
+    , m_iCounter(0)
 {
     ls_mutex_setup(&m_mutex);
+    ls_mutex_setup(&m_udns_mutex);
 
     evtcbhead_reset(this);
 }
@@ -371,10 +387,16 @@ AdnsReq *Adns::getHostByName(const char * pName, int type,
     pAdnsReq->cb = cb;
     pAdnsReq->arg = arg;
     pAdnsReq->start_time = DateTime::s_curTime;
+
+    bool need_lock = (!m_lockedBy || !pthread_equal(m_lockedBy, pthread_self()));
+    if (need_lock)
+        ls_mutex_lock(&m_udns_mutex);
     if (type != PF_INET6)
         pQuery = dns_submit_a4( m_pCtx, pName, DNS_NOSRCH, (addrLookupCbV4)getHostByNameCb, pAdnsReq);
     else
         pQuery = dns_submit_a6( m_pCtx, pName, DNS_NOSRCH, (addrLookupCbV6)getHostByNameCb, pAdnsReq);
+    if (need_lock)
+        ls_mutex_unlock(&m_udns_mutex);
     if (pQuery == NULL)
     {
         delete pAdnsReq;
@@ -430,10 +452,16 @@ AdnsReq * Adns::getHostByAddr(const struct sockaddr * pAddr, void *arg, lookup_p
     pAdnsReq->arg = arg;
     pAdnsReq->start_time = DateTime::s_curTime;
 
+    bool need_lock = (!m_lockedBy || !pthread_equal(m_lockedBy, pthread_self()));
+    if (need_lock)
+        ls_mutex_lock(&m_udns_mutex);
     if (type != PF_INET6)
         pQuery = dns_submit_a4ptr( m_pCtx, (in_addr *)pName, getHostByAddrCb, pAdnsReq);
     else
         pQuery = dns_submit_a6ptr( m_pCtx, (in6_addr *)pName, getHostByAddrCb, pAdnsReq);
+    if (need_lock)
+        ls_mutex_unlock(&m_udns_mutex);
+
     if (pQuery == NULL)
     {
         delete pAdnsReq;
@@ -448,7 +476,13 @@ AdnsReq * Adns::getHostByAddr(const struct sockaddr * pAddr, void *arg, lookup_p
 int Adns::handleEvents( short events )
 {
     if ( events & POLLIN )
-        dns_ioevent( m_pCtx, DateTime::s_curTime );
+    {
+        ls_mutex_lock(&m_udns_mutex);
+        m_lockedBy = pthread_self();
+        dns_ioevent(m_pCtx, DateTime::s_curTime);
+        m_lockedBy = 0;
+        ls_mutex_unlock(&m_udns_mutex);
+    }
     return 0;
 }
 
@@ -472,7 +506,11 @@ void Adns::setTimeOut(int tmSec)
 
 void Adns::checkDnsEvents()
 {
-    dns_timeouts( m_pCtx, -1, DateTime::s_curTime );
+    ls_mutex_lock(&m_udns_mutex);
+    m_lockedBy = pthread_self();
+    dns_timeouts(m_pCtx, -1, DateTime::s_curTime);
+    m_lockedBy = 0;
+    ls_mutex_unlock(&m_udns_mutex);
 }
 
 
@@ -532,3 +570,92 @@ int Adns::getHostByNameV6Sync(const char *pName, in6_addr *addr)
     }
     return -1;
 }
+
+
+AdnsFetch::AdnsFetch()
+    : m_pAdnsReq(NULL)
+{
+}
+
+
+AdnsFetch::~AdnsFetch()
+{
+    release();
+}
+
+
+int AdnsFetch::tryResolve(const char *name_port, char *name_only,
+                          int family, int flag)
+{
+    int  gotAddr = m_resolvedAddr.set2(family, name_port, flag, name_only);
+
+    if (gotAddr == -1)
+        return LS_FAIL;
+    else if (gotAddr == 1)
+        return LS_OK;
+
+    if (!(flag & SKIP_ADNS_CACHE))
+    {
+        int ipLen;
+        const char *pIp = Adns::getInstance().getHostByNameInCache(name_only,
+                            ipLen, family);
+        if (pIp)
+        {
+            return m_resolvedAddr.setIp(m_resolvedAddr.get(), pIp, ipLen);
+        }
+    }
+    return LS_FAIL;
+}
+
+
+int AdnsFetch::asyncLookup(int family, const char *name_only,
+                           lookup_pf callback, void *param)
+{
+    AdnsReq *req;
+
+    if (!callback)
+        return LS_FAIL;
+
+    req = Adns::getInstance().getHostByName(name_only, family, callback, param);
+
+    if (req)
+    {
+         if (m_pAdnsReq)
+             release();
+         m_pAdnsReq = req;
+         req->incRefCount();
+         return LS_TRUE;
+    }
+    return LS_FAIL;
+}
+
+
+int AdnsFetch::setResolvedIp(const void *pIP, int ip_len)
+{
+    int ret = m_resolvedAddr.setIp(m_resolvedAddr.get(), pIP, ip_len);
+    return ret;
+}
+
+
+void AdnsFetch::setResolvedAddr(const sockaddr *addr)
+{
+    m_resolvedAddr.set(addr);
+}
+
+
+void AdnsFetch::cancel()
+{
+    release();
+}
+
+
+void AdnsFetch::release()
+{
+    if (m_pAdnsReq)
+    {
+        m_pAdnsReq->setCallback(NULL);
+        Adns::release(m_pAdnsReq);
+        m_pAdnsReq = NULL;
+    }
+}
+
