@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2021  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -55,6 +55,7 @@ class HttpLog
     ~HttpLog();
 public:
     static void init();
+    static void updateLogPatternWithPid(int pid);
     static void setServerRoot(const char *s) { s_serverRoot.setStr(s);  }
     static int logAccess(const char *pVHost, int len, HttpSession *pSession);
     static void error_num(int __errnum, const char *__file,
@@ -89,6 +90,7 @@ public:
     static void setDebugLevel(int level);
     static void toggleDebugLog();
 
+    static int  getLogLevel();
     static void setLogLevel(int level);
     static void setLogLevel(const char *pLevel);
     static void setLogPattern(const char *pPattern);
