@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2021  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -212,7 +212,7 @@ int HttpLogSource::initAllLog(const char *pRoot)
     setErrorLogFile(achBuf);
     setLogLevel("DEBUG");
     off_t rollSize = 1024 * 10240;
-    setErrorLogRollingSize(rollSize, 30);
+    setErrorLogRollingSize(rollSize, 30, 0);
     HttpLog::setDebugLevel(0);
 
     lstrncpy(pEnd, "/logs/stderr.log", sizeof(achBuf) - (pEnd - p));
@@ -259,7 +259,9 @@ int HttpLogSource::initErrorLog2(const XmlNode *pNode,
                 INT_MAX, 1024 * 10240);
     int days = ConfigCtx::getCurConfigCtx()->getLongValue(pNode, "keepDays", 0,
                LLONG_MAX, 30);
-    setErrorLogRollingSize(rollSize, days);
+    int compress = ConfigCtx::getCurConfigCtx()->getLongValue(pNode, "compressArchive", -1,
+               1, -1);
+    setErrorLogRollingSize(rollSize, days, compress);
 
     m_iAioErrorLog = ConfigCtx::getCurConfigCtx()->getLongValue(pNode,
                      "enableaiolog", 0, 1, -1);
