@@ -47,6 +47,7 @@ static char DEFAULT_MIME_TYPE[] = "application/octet-stream";
 static StringList *s_pMIMEList = NULL;
 
 HttpMime *HttpMime::s_pMime = NULL;
+MimeSetting *HttpMime::s_pBlankMime = NULL;
 
 //class MimeSettingList : public TPointerList<MimeSetting>{};
 
@@ -708,6 +709,16 @@ MimeSetting *HttpMime::initDefault(char *pMIME)
 }
 
 
+void HttpMime::initBlank()
+{
+    if (!s_pBlankMime)
+    {
+        s_pBlankMime = new MimeSetting();
+        s_pBlankMime->setMIME(::getMIME(""));
+    }
+}
+
+
 const MimeSetting *HttpMime::getMimeSetting(char *pMime) const
 {
     return m_pMIMEMap->findMimeIgnoreCharset(pMime);
