@@ -79,6 +79,7 @@ private:
     MIMESuffixMap    *m_pSuffixMap;
     MimeSetting      *m_pDefault;
     static HttpMime  *s_pMime;
+    static MimeSetting * s_pBlankMime;
 
     void operator=(const HttpMime &rhs) {}
 
@@ -149,6 +150,9 @@ public:
                                HttpMime *pHttpMime,
                                const char *pSuffix);
 
+    static void initBlank();
+    static MimeSetting *getBlank()      {   return s_pBlankMime;    }
+
     static void setMime(HttpMime *pMime)
     {   s_pMime = pMime;    }
     static HttpMime *getMime()
