@@ -355,7 +355,7 @@ int NtwkIOLink::setLink(HttpListener *pListener,  int fd, ConnInfo *pInfo)
     }
 
     getClientInfo()->incConn();
-    LS_DBG_L(this, "concurrent conn: %zd", pInfo->m_pClientInfo->getConns());
+    LS_DBG_L(this, "concurrent conn: %d", pInfo->m_pClientInfo->getConns());
 
     //FIXME below code is from lslbd, should we use this flag?
 //     if (pInfo->m_pClientInfo->isFromLocalAddr(
@@ -875,6 +875,11 @@ int NtwkIOLink::shutdown()
         if (!isPeerShutdown())
         {
             releaseHandler();
+            if (m_iHeaderToSend > 0)
+            {
+                m_iov.clear();
+                m_iHeaderToSend = 0;
+            }
             if (getState() == HIOS_CONNECTED)
                 setState(HIOS_CLOSING);
             MultiplexerFactory::getMultiplexer()->continueWrite(this);
@@ -912,7 +917,7 @@ int NtwkIOLink::close_(NtwkIOLink *pThis)
             ConnLimitCtrl::getInstance().decConn();
             pThis->getClientInfo()->decConn();
             pThis->m_iPeerShutdown |= IO_COUNTED;
-            LS_DBG_L(pThis, "Available Connections: %d, concurrent conn: %zd.",
+            LS_DBG_L(pThis, "Available Connections: %d, concurrent conn: %d.",
                      ConnLimitCtrl::getInstance().availConn(),
                      pThis->getClientInfo()->getConns());
         }
@@ -945,7 +950,7 @@ void NtwkIOLink::closeSocket()
     {
         ctrl.decConn();
         getClientInfo()->decConn();
-        LS_DBG_L(this, "Available Connections: %d, concurrent conn: %zd",
+        LS_DBG_L(this, "Available Connections: %d, concurrent conn: %d",
                  ctrl.availConn(), getClientInfo()->getConns());
     }
 
@@ -998,6 +1003,13 @@ void NtwkIOLink::releaseIdleSslBuffer()
 }
 
 
+void NtwkIOLink::enableSocketKeepAlive()
+{
+    int v = 1;
+    setsockopt(getfd(), SOL_SOCKET, SO_KEEPALIVE, (char *) &v, sizeof (int));
+}
+
+
 int NtwkIOLink::onTimer()
 {
     if (matchToken(this->m_tmToken))
