@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2021  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -49,6 +49,7 @@ public:
             m_iAvailable -= n;          }
     void    adjustLimit(int n)
     {   m_iAvailable += (n - m_iLimit);   m_iLimit = (n > 0) ? n : THROTTLE_MAX;       }
+    bool    isUnlimited() const {   return m_iLimit == THROTTLE_MAX;    }
 
 };
 
@@ -114,6 +115,11 @@ public:
     ThrottleUnit *getThrottleUnit(int dyn)
     {   return &m_req[dyn];   }
 
+    ThrottleUnit *getThrottleIn()
+    {   return &m_input;   }
+    ThrottleUnit *getThrottleOut()
+    {   return &m_output;  }
+
     void incReqProcessed(int dyn)
     {
         m_req[dyn].used(1);
