@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2020 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 #include <assert.h>
 #include <inttypes.h>
 #include <stddef.h>
@@ -37,6 +37,7 @@ lsquic_bw_sampler_init (struct bw_sampler *sampler, struct lsquic_conn *conn,
     sampler->bws_malo = malo;
     sampler->bws_conn = conn;
     sampler->bws_retx_frames = retx_frames;
+    sampler->bws_flags |= BWS_APP_LIMITED;
     LSQ_DEBUG("init");
     return 0;
 }
@@ -58,7 +59,10 @@ lsquic_bw_sampler_cleanup (struct bw_sampler *sampler)
     if (sampler->bws_conn)
         LSQ_DEBUG("cleanup");
     if (sampler->bws_malo)
+    {
         lsquic_malo_destroy(sampler->bws_malo);
+        sampler->bws_malo = NULL;
+    }
 }
 
 
@@ -79,11 +83,11 @@ bw_sampler_abort_conn (struct bw_sampler *sampler)
 }
 
 
-#define BW_WARN_ONCE(msg...) do {                                           \
+#define BW_WARN_ONCE(...) do {                                              \
     if (!(sampler->bws_flags & BWS_WARNED))                                 \
     {                                                                       \
         sampler->bws_flags |= BWS_WARNED;                                   \
-        LSQ_WARN(msg);                                                      \
+        LSQ_WARN(__VA_ARGS__);                                              \
     }                                                                       \
 } while (0)
 
