@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2020 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 #ifndef __LSQUIC_CRT_COMPRESS_H__
 #define __LSQUIC_CRT_COMPRESS_H__
 
@@ -34,20 +34,31 @@ typedef struct common_cert_st
     uint64_t hash;
 } common_cert_t;
 
-struct lsquic_str * get_common_certs_hash();
+int
+lsquic_crt_init (void);
+
+struct lsquic_str * lsquic_get_common_certs_hash();
 
 
-int get_common_cert(uint64_t hash, uint32_t index, struct lsquic_str *buf);
-int match_common_cert(struct lsquic_str * cert, struct lsquic_str * common_set_hashes,
-                      uint64_t* out_hash, uint32_t* out_index);
+int lsquic_get_common_cert(uint64_t hash, uint32_t index, struct lsquic_str *buf);
 
-int compress_certs(struct lsquic_str **certs, size_t certs_count,
+struct compressed_cert
+{
+    size_t          len;
+    unsigned        refcnt;
+    unsigned char   buf[0]; /* len bytes */
+};
+
+/* Returns newly allocated structure or NULL on error */
+struct compressed_cert *
+lsquic_compress_certs(struct lsquic_str **certs, size_t certs_count,
                    struct lsquic_str *client_common_set_hashes,
-                   struct lsquic_str *client_cached_cert_hashes,
-                   struct lsquic_str *result);
+                   struct lsquic_str *client_cached_cert_hashes);
 
-int get_certs_count(struct lsquic_str *compressed_crt_buf);
-int decompress_certs(const unsigned char *in, const unsigned char *in_end,
+int
+lsquic_get_certs_count (const struct compressed_cert *);
+
+int lsquic_decompress_certs(const unsigned char *in, const unsigned char *in_end,
                      struct lsquic_str *cached_certs, size_t cached_certs_count,
                      struct lsquic_str **out_certs, 
                      size_t *out_certs_count);
