@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2020 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 #ifndef LSQUIC_PACKET_GQUIC_H
 #define LSQUIC_PACKET_GQUIC_H 1
 
@@ -16,12 +16,6 @@ enum PACKET_PUBLIC_FLAGS
   PACKET_PUBLIC_FLAGS_TWO_OR_MORE_BYTES = 1 << 7,
 };
 
-#define GQUIC_FRAME_REGEN_MASK ((1 << QUIC_FRAME_ACK)                \
-  | (1 << QUIC_FRAME_PATH_CHALLENGE) | (1 << QUIC_FRAME_PATH_RESPONSE) \
-  | (1 << QUIC_FRAME_STOP_WAITING) | (1 << QUIC_FRAME_TIMESTAMP))
-
-#define GQUIC_FRAME_REGENERATE(frame_type) ((1 << (frame_type)) & GQUIC_FRAME_REGEN_MASK)
-
 #define GQUIC_FRAME_ACKABLE_MASK (                               \
     (1 << QUIC_FRAME_STREAM)                                \
   | (1 << QUIC_FRAME_RST_STREAM)                            \
@@ -92,7 +86,7 @@ enum PACKET_PUBLIC_FLAGS
 #define gquic_packno_bits2len(b) (((b) << 1) + !(b))
 
 lsquic_packno_t
-restore_packno (lsquic_packno_t cur_packno,
+lsquic_restore_packno (lsquic_packno_t cur_packno,
                 unsigned packet_len,
                 lsquic_packno_t max_packno);
 
