@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2019 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 #ifndef LSQUIC_PACKET_IETF_H
 #define LSQUIC_PACKET_IETF_H 1
 
@@ -20,4 +20,14 @@
  */
 #define MIN_INITIAL_DCID_LEN 8
 
+/* [draft-ietf-quic-transport-24] Section 8.1 */
+#define IQUIC_MIN_INIT_PACKET_SZ 1200
+
+/* Our stream code makes an assumption that packet size is smaller than the
+ * maximum HTTP/3 DATA frame size we can generate.
+ */
+#define IQUIC_MAX_OUT_PACKET_SZ ((1u << 14) - 1)
+
+#define QUIC_BIT 0x40
+
 #endif
