@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2020 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 /*
  * lsquic_parse_Q046.c -- Parsing functions specific to GQUIC Q046
  */
@@ -188,7 +188,7 @@ gen_long_pkt_header (const struct lsquic_conn *lconn,
 static int
 gquic_Q046_gen_reg_pkt_header (const struct lsquic_conn *lconn,
             const struct lsquic_packet_out *packet_out, unsigned char *buf,
-                                                                size_t bufsz)
+        size_t bufsz, unsigned *packno_off_UNUSED, unsigned *packno_len_UNUSED)
 {
     if (0 == (packet_out->po_flags & PO_LONGHEAD))
         return gen_short_pkt_header(lconn, packet_out, buf, bufsz);
@@ -215,7 +215,8 @@ gquic_Q046_packout_header_size_short (const struct lsquic_conn *lconn,
 
 static size_t
 gquic_Q046_packout_header_size (const struct lsquic_conn *lconn,
-                            enum packet_out_flags flags, size_t dcid_len_unused)
+                            enum packet_out_flags flags, size_t dcid_len_unused,
+                            enum header_type unused)
 {
     if (0 == (flags & PO_LONGHEAD))
         return gquic_Q046_packout_header_size_short(lconn, flags);
@@ -242,7 +243,7 @@ gquic_Q046_packout_size (const struct lsquic_conn *lconn,
 }
 
 
-void
+static void
 gquic_Q046_parse_packet_in_finish (struct lsquic_packet_in *packet_in,
                                             struct packin_parse_state *state)
 {
@@ -264,7 +265,8 @@ gquic_Q046_parse_packet_in_finish (struct lsquic_packet_in *packet_in,
 
 static int
 gquic_Q046_gen_crypto_frame (unsigned char *buf, size_t buf_len,
-        uint64_t offset, size_t size, gcf_read_f gcf_read, void *stream)
+        lsquic_stream_id_t stream_id, uint64_t offset, int fin, size_t size,
+        gsf_read_f gsf_read, void *stream)
 {
     assert(0);
     return -1;
@@ -280,15 +282,6 @@ gquic_Q046_parse_crypto_frame (const unsigned char *buf, size_t rem_packet_sz,
 }
 
 
-static void
-gquic_Q046_packno_info (const struct lsquic_conn *lconn,
-        const struct lsquic_packet_out *packet_out, unsigned *packno_off,
-        unsigned *packno_len)
-{
-    assert(0);
-}
-
-
 /* No simple PRST for Q046 */
 static ssize_t
 gquic_Q046_generate_simple_prst (const lsquic_cid_t *cidp, unsigned char *buf,
@@ -323,29 +316,30 @@ const struct parse_funcs lsquic_parse_funcs_gquic_Q046 =
 {
     .pf_gen_reg_pkt_header            =  gquic_Q046_gen_reg_pkt_header,
     .pf_parse_packet_in_finish        =  gquic_Q046_parse_packet_in_finish,
-    .pf_gen_stream_frame              =  gquic_be_gen_stream_frame,
-    .pf_calc_stream_frame_header_sz   =  calc_stream_frame_header_sz_gquic,
-    .pf_parse_stream_frame            =  gquic_be_parse_stream_frame,
-    .pf_parse_ack_frame               =  gquic_be_parse_ack_frame,
-    .pf_gen_ack_frame                 =  gquic_be_gen_ack_frame,
-    .pf_gen_stop_waiting_frame        =  gquic_be_gen_stop_waiting_frame,
-    .pf_parse_stop_waiting_frame      =  gquic_be_parse_stop_waiting_frame,
-    .pf_skip_stop_waiting_frame       =  gquic_be_skip_stop_waiting_frame,
-    .pf_gen_window_update_frame       =  gquic_be_gen_window_update_frame,
-    .pf_parse_window_update_frame     =  gquic_be_parse_window_update_frame,
-    .pf_gen_blocked_frame             =  gquic_be_gen_blocked_frame,
-    .pf_parse_blocked_frame           =  gquic_be_parse_blocked_frame,
-    .pf_gen_rst_frame                 =  gquic_be_gen_rst_frame,
-    .pf_parse_rst_frame               =  gquic_be_parse_rst_frame,
-    .pf_connect_close_frame_size      =  gquic_be_connect_close_frame_size,
-    .pf_gen_connect_close_frame       =  gquic_be_gen_connect_close_frame,
-    .pf_parse_connect_close_frame     =  gquic_be_parse_connect_close_frame,
-    .pf_gen_goaway_frame              =  gquic_be_gen_goaway_frame,
-    .pf_parse_goaway_frame            =  gquic_be_parse_goaway_frame,
-    .pf_gen_ping_frame                =  gquic_be_gen_ping_frame,
+    .pf_gen_stream_frame              =  lsquic_gquic_be_gen_stream_frame,
+    .pf_calc_stream_frame_header_sz   =  lsquic_calc_stream_frame_header_sz_gquic,
+    .pf_parse_stream_frame            =  lsquic_gquic_be_parse_stream_frame,
+    .pf_dec_stream_frame_size         =  lsquic_gquic_be_dec_stream_frame_size,
+    .pf_parse_ack_frame               =  lsquic_gquic_be_parse_ack_frame,
+    .pf_gen_ack_frame                 =  lsquic_gquic_be_gen_ack_frame,
+    .pf_gen_stop_waiting_frame        =  lsquic_gquic_be_gen_stop_waiting_frame,
+    .pf_parse_stop_waiting_frame      =  lsquic_gquic_be_parse_stop_waiting_frame,
+    .pf_skip_stop_waiting_frame       =  lsquic_gquic_be_skip_stop_waiting_frame,
+    .pf_gen_window_update_frame       =  lsquic_gquic_be_gen_window_update_frame,
+    .pf_parse_window_update_frame     =  lsquic_gquic_be_parse_window_update_frame,
+    .pf_gen_blocked_frame             =  lsquic_gquic_be_gen_blocked_frame,
+    .pf_parse_blocked_frame           =  lsquic_gquic_be_parse_blocked_frame,
+    .pf_gen_rst_frame                 =  lsquic_gquic_be_gen_rst_frame,
+    .pf_parse_rst_frame               =  lsquic_gquic_be_parse_rst_frame,
+    .pf_connect_close_frame_size      =  lsquic_gquic_be_connect_close_frame_size,
+    .pf_gen_connect_close_frame       =  lsquic_gquic_be_gen_connect_close_frame,
+    .pf_parse_connect_close_frame     =  lsquic_gquic_be_parse_connect_close_frame,
+    .pf_gen_goaway_frame              =  lsquic_gquic_be_gen_goaway_frame,
+    .pf_parse_goaway_frame            =  lsquic_gquic_be_parse_goaway_frame,
+    .pf_gen_ping_frame                =  lsquic_gquic_be_gen_ping_frame,
 #ifndef NDEBUG
-    .pf_write_float_time16            =  gquic_be_write_float_time16,
-    .pf_read_float_time16             =  gquic_be_read_float_time16,
+    .pf_write_float_time16            =  lsquic_gquic_be_write_float_time16,
+    .pf_read_float_time16             =  lsquic_gquic_be_read_float_time16,
 #endif
     .pf_generate_simple_prst          =  gquic_Q046_generate_simple_prst,
     .pf_parse_frame_type              =  lsquic_parse_frame_type_gquic_Q035_thru_Q046,
@@ -356,7 +350,6 @@ const struct parse_funcs lsquic_parse_funcs_gquic_Q046 =
     .pf_packno_bits2len               =  gquic_Q046_packno_bits2len,
     .pf_gen_crypto_frame              =  gquic_Q046_gen_crypto_frame,
     .pf_parse_crypto_frame            =  gquic_Q046_parse_crypto_frame,
-    .pf_packno_info                   =  gquic_Q046_packno_info,
     .pf_gen_handshake_done_frame      =  gquic_Q046_gen_handshake_done_frame,
     .pf_parse_handshake_done_frame    =  gquic_Q046_parse_handshake_done_frame,
     .pf_handshake_done_frame_size     =  gquic_Q046_handshake_done_frame_size,
