@@ -1,18 +1,14 @@
-/* Copyright (c) 2017 - 2020 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 #ifndef LSQUIC_PUSH_PROMISE_H
 #define LSQUIC_PUSH_PROMISE_H 1
 
-struct lsquic_hash_elem;
-struct lsquic_stream;
-
 
 struct push_promise
 {
     /* A push promise is associated with a single stream, while a stream can
      * have several push promises it depends on.  These push promises are
      * stored on a list.  A push promise is destroyed when the dependent
-     * stream is destroyed.  This bounds the amount of time when DUPLICATE_PUSH
-     * frames can be sent out.
+     * stream is destroyed.
      */
     SLIST_ENTRY(push_promise)   pp_next;
     /* Push promises are stored a hash and can be searched by ID */
