@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2020 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 /*
  * Utility functions
  */
@@ -6,17 +6,19 @@
 #include <ctype.h>
 #include <stdint.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <time.h>
 #ifndef WIN32
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <sys/socket.h>
 #include <sys/time.h>
 #include <unistd.h>
 #else
 #include <vc_compat.h>
+#include <ws2tcpip.h>
 #endif
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <sys/socket.h>
 
 #if !(defined(_POSIX_TIMERS) && _POSIX_TIMERS > 0) && defined(__APPLE__)
 #include <mach/mach_time.h>
@@ -125,7 +127,8 @@ lsquic_is_zero (const void *pbuf, size_t bufsz)
 
 
 /* XXX this function uses static buffer.  Replace it with lsquic_hexdump() if possible */
-char *get_bin_str(const void *s, size_t len, size_t max_display_len)
+char *
+lsquic_get_bin_str (const void *s, size_t len, size_t max_display_len)
 {
     const unsigned char *p, *pEnd;
     char *pOutput; 
@@ -311,3 +314,23 @@ lsquic_sockaddr2str (const struct sockaddr *addr, char *buf, size_t sz)
     if (len < (int) sz)
         snprintf(buf + len, sz - (size_t) len, ":%hu", port);
 }
+
+
+#ifdef _MSC_VER
+char *
+lsquic_strndup (const char *s, size_t n)
+{
+    size_t len;
+    char *copy;
+
+    len = strnlen(s, n);
+    copy = malloc(n + 1);
+    if (copy)
+    {
+        memcpy(copy, s, len);
+        copy[len] = '\0';
+    }
+
+    return copy;
+}
+#endif
