@@ -1,4 +1,4 @@
-/* Copyright (c) 2017 - 2019 LiteSpeed Technologies Inc.  See LICENSE. */
+/* Copyright (c) 2017 - 2021 LiteSpeed Technologies Inc.  See LICENSE. */
 /*
  * lsquic_util.h -- Utility functions
  */
@@ -10,6 +10,8 @@
 extern "C" {
 #endif
 
+struct sockaddr;
+
 lsquic_time_t
 lsquic_time_now (void);
 
@@ -23,7 +25,8 @@ lsquic_is_zero (const void *buf, size_t bufsz);
 
 
 
-char * get_bin_str(const void *s, size_t len, size_t max_display_len);
+char *
+lsquic_get_bin_str (const void *s, size_t len, size_t max_display_len);
 
 size_t
 lsquic_hex_encode (const void *src, size_t src_sz, void *dst, size_t dst_sz);
@@ -38,6 +41,20 @@ lsquic_hexstr (const unsigned char *buf, size_t bufsz, char *out, size_t outsz);
 #define HEXSTR(buf, bufsz, out) \
     (lsquic_hexstr(buf, bufsz, out, sizeof(out)), out)
 
+int
+lsquic_sockaddr_eq (const struct sockaddr *a, const struct sockaddr *b);
+
+void
+lsquic_sockaddr2str (const struct sockaddr *addr, char *buf, size_t sz);
+
+#define SA2STR(sa_, buf_) (lsquic_sockaddr2str(sa_, buf_, sizeof(buf_)), buf_)
+
+#ifdef _MSC_VER
+char *
+lsquic_strndup(const char *s, size_t n);
+#define strndup lsquic_strndup
+#endif
+
 #ifdef __cplusplus
 }
 #endif
