@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2021  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -36,7 +36,7 @@ private:
     lsi_callback_pf m_cb;
 
 public:
-    EnvHandler()    {   m_pName = NULL; m_iLen = 0;   };
+    EnvHandler()    {   m_pName = NULL; m_iLen = 0; m_cb = NULL;  };
     ~EnvHandler()   {   if (m_pName) free(m_pName);  };
 
 
