@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2021  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -958,7 +958,7 @@ int ModuleConfig::parseConfig(const XmlNode *pNode, lsi_module_t *pModule,
         ModuleConfig::setFilterEnable(config, atoi(pValue));
 
     pValue = pNode->getChildValue("param");
-    iValueLen = pNode->getChildValueLen("param");
+    iValueLen = pNode->getChildValueLen("param", 0);
 
     config->data_flag = LSI_CONFDATA_NONE;
     if (pModule->config_parser && pModule->config_parser->parse_config)
