@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2021  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -26,8 +26,8 @@
 class session;
 
 #define MNAME                       mod_security
-#define ModuleNameStr               "Mod_Security"
-#define VERSIONNUMBER               "1.3"
+#define ModuleNameStr               "mod_security"
+#define VERSIONNUMBER               "1.4"
 
 #define MODULE_VERSION_INFO         ModuleNameStr " " VERSIONNUMBER
 
@@ -292,12 +292,15 @@ static int process_intervention (Transaction *t, lsi_param_t *rec)
         free(intervention.url);
     }
 
+    const char *log;
     if (intervention.log == NULL) {
-        intervention.log = (char *)"(no log message was specified)";
+        log = "(no log message was specified)";
         g_api->log(rec->session, LSI_LOG_DEBUG, "[Module:%s]"
                    "No log message specified\n",
                    ModuleNameStr);
     }
+    else
+        log = intervention.log;
     g_api->log(rec->session, LSI_LOG_INFO, "[Module:%s]"
                "Intervention status code triggered: %d\n",
                ModuleNameStr, intervention.status);
@@ -305,9 +308,11 @@ static int process_intervention (Transaction *t, lsi_param_t *rec)
         // NOT always logged in callback
         g_api->log(rec->session, LSI_LOG_INFO, "[Module:%s]"
                    "Log Message: %s\n",
-                   ModuleNameStr, intervention.log);
+                   ModuleNameStr, log);
     }
     g_api->set_status_code(rec->session, intervention.status);
+    if (intervention.log)
+        free(intervention.log);
     return intervention.status;
 }
 
