@@ -16,9 +16,9 @@ int ReusePortFds::passFds(const char *type, const char *addr, int target_fd)
         if (fd != -1)
         {
             --target_fd;
+            ++count;
             LS_INFO("[%s %s], SO_REUSEPORT #%d, pass listener copy fd %d to %d.",
                     type, addr, count, fd, target_fd);
-            ++count;
             dup2(fd, target_fd);
             ls_close(fd);
         }
@@ -44,6 +44,25 @@ int ReusePortFds::getFdCount(int* maxfd)
 }
 
 
+int ReusePortFds::shrink(int new_size)
+{
+    int old_size = size();
+    if (new_size >= old_size)
+        return 0;
+    int i;
+    for(i = new_size; i < old_size; ++i)
+    {
+        if ((*this)[i] != -1)
+        {
+             ls_close((*this)[i]);
+             (*this)[i] = -1;
+        }
+    }
+    setSize(new_size);
+    return 0;
+}
+
+
 void ReusePortFds::close()
 {
     int i;
@@ -51,7 +70,7 @@ void ReusePortFds::close()
     {
         if ((*this)[i] != -1)
         {
-            LS_INFO("Close SO_REUSEPORT %d.", (*this)[i]);
+            LS_INFO("Close SO_REUSEPORT #%d fd: %d.", i + 1, (*this)[i]);
             ls_close((*this)[i]);
             (*this)[i] = -1;
         }
